# NetworkResult

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project_id** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**data_center_id** | **str** |  | [optional] 
**ip_range** | **str** |  | [optional] 
**gateway** | **str** |  | [optional] 
**internal_ip_address** | **str** |  | [optional] 
**external_ip_address** | **str** |  | [optional] 
**state** | [**NetworkState**](NetworkState.md) |  | [optional] 
**create_time** | **datetime** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


